RBMoniData

Struct RBMoniData 

pub struct RBMoniData {
Show 39 fields pub board_id: u8, pub rate: u16, pub tmp_drs: f32, pub tmp_clk: f32, pub tmp_adc: f32, pub tmp_zynq: f32, pub tmp_lis3mdltr: f32, pub tmp_bm280: f32, pub pressure: f32, pub humidity: f32, pub mag_x: f32, pub mag_y: f32, pub mag_z: f32, pub lost_event_ids: f32, pub drs_dvdd_voltage: f32, pub drs_dvdd_current: f32, pub drs_dvdd_power: f32, pub p3v3_voltage: f32, pub p3v3_current: f32, pub p3v3_power: f32, pub zynq_voltage: f32, pub zynq_current: f32, pub zynq_power: f32, pub p3v5_voltage: f32, pub p3v5_current: f32, pub p3v5_power: f32, pub adc_dvdd_voltage: f32, pub adc_dvdd_current: f32, pub adc_dvdd_power: f32, pub adc_avdd_voltage: f32, pub adc_avdd_current: f32, pub adc_avdd_power: f32, pub drs_avdd_voltage: f32, pub drs_avdd_current: f32, pub drs_avdd_power: f32, pub n1v5_voltage: f32, pub n1v5_current: f32, pub n1v5_power: f32, pub timestamp: u64,
}
Sensors on the individual RB

This includes temperatures, power data, pressure, humidity as well as the magnetic sensors

Fields

board_id: u8rate: u16tmp_drs: f32tmp_clk: f32tmp_adc: f32tmp_zynq: f32tmp_lis3mdltr: f32tmp_bm280: f32pressure: f32humidity: f32mag_x: f32mag_y: f32mag_z: f32lost_event_ids: f32drs_dvdd_voltage: f32drs_dvdd_current: f32drs_dvdd_power: f32p3v3_voltage: f32p3v3_current: f32p3v3_power: f32zynq_voltage: f32zynq_current: f32zynq_power: f32p3v5_voltage: f32p3v5_current: f32p3v5_power: f32adc_dvdd_voltage: f32adc_dvdd_current: f32adc_dvdd_power: f32adc_avdd_voltage: f32adc_avdd_current: f32adc_avdd_power: f32drs_avdd_voltage: f32drs_avdd_current: f32drs_avdd_power: f32n1v5_voltage: f32n1v5_current: f32n1v5_power: f32timestamp: u64

Implementations

Source

impl RBMoniData

pub fn new() -> Self

pub fn add_rbvcp(&mut self, rb_vcp: &RBVcp)

pub fn add_rbph(&mut self, rb_ph: &RBPh)

pub fn add_rbtemp(&mut self, rb_temp: &RBTemp)

pub fn add_rbmag(&mut self, rb_mag: &RBMag)

pub fn get_mag_tot(&self) -> f32

pub fn get_lost_event_ids_over_rate(&self) -> f32

Get the rate-weighted number of event ids which were found unusable by the RB